import os

from cryptography.fernet import Fernet
from typeguard import typechecked

from daves_utilities.credentials import credentials

@typechecked
def get_david_secret() -> str:
    key = os.getenv("DAVID_SECRET")
    if key is None:
        raise ValueError("Environment variable DAVID_SECRET is not set")
    return key

@typechecked
def create_fernet_key() -> Fernet:
    key = get_david_secret()
    return Fernet(key)

@typechecked
def generate_key() -> bytes:
    return Fernet.generate_key()

@typechecked
def encrypt_message(message: str) -> bytes:
    fernet = create_fernet_key()
    return fernet.encrypt(message.encode())

@typechecked
def decrypt_message(enc_message: bytes) -> str:
    fernet = create_fernet_key()
    return fernet.decrypt(enc_message).decode()

@typechecked
def get_credentials(credential_name: str) -> dict[str, str]:
    crd = credentials[credential_name]
    return {"usr": crd["usr"], "pwd": decrypt_message(crd["pwd"])}


if __name__ == "__main__":
    message = "<pwd>"
    print(f"{message=}")

    enc_message = encrypt_message(message)
    print(f"{enc_message=}")

    dec_message = decrypt_message(enc_message)
    print(f"{dec_message=}")



credentials = {
    "pytest":{
        # This is a test user and should not be used anywhere else
        # password is stored in bitwarden "daves_utilities - pytest"
        "usr": 'david_pytest',
        "pwd": (
            b'gAAAAABmJ7g8NDtWLZ1Pw4S68krPteAYDRk4ZcRYiOSEWo8h9HZmLp6VejU7qbi6asv8CF'
            b'Kwnl5gOirOWeg5gwmkFcOmKC5Zlq7vE4-rTg4iBsyPssAu9Eg='
        )
    },
    "postgres":{
        # password is stored in bitwarden "daves_utilities - postgres"
        "usr": 'david_postgres',
        "pwd": (
            b'gAAAAABmJr3YNnZGzXTTqLvaDgCGz-AoY93XoqeZbXjcRzHLOkPXGmQP5ucccFjVFjTwmqj'
            b'Z0UOl605cGGrvDCBfO2rm7qB9tAlHSEGZqfYjib2glzGSNz0='
        )
    },
    "fastapi":{
        # password is stored in bitwarden "daves_utilities - fastapi"
        "usr": 'david_fastapi',
        "pwd": (
            b'gAAAAABmJr5XjnJBx0MtbGkgnKEQdgYR_LZKIuC1BnywXaMGXsXCpSlqukdHu4z6dcANSf6'
            b'K3pBJsacF01WQj_6ykile6juE0J0vu9MNV08SBJN0dwtpVcY='
        )
    },
}
